# SUS03: How do you take advantage of software and architecture patterns to support sustainability?

## References

- [AWS SUS03](https://docs.aws.amazon.com/wellarchitected/latest/framework/sus-03.html)
- [Green Software Foundation](https://greensoftware.foundation/)
- [ISO/IEC 21031:2024](https://www.iso.org/standard/86612.html)

## Date

2025-11-27

## Focus Area

Software and Architecture

## Best Practices

### SUS03-BP01: Optimize software and architecture for asynchronous patterns
Async processing.

### SUS03-BP02: Optimize software and architecture for buffering
Batch processing.

### SUS03-BP03: Optimize software and architecture for caching
Reduce redundant processing.

### SUS03-BP04: Use software patterns for sustainability
Green software patterns.

## Green Software Principles

1. **Carbon efficiency**: Emit least carbon possible
2. **Energy efficiency**: Use least energy possible
3. **Carbon awareness**: Do more when grid is green
4. **Hardware efficiency**: Use least hardware possible
5. **Measurement**: Measure and track carbon emissions

## Checklist

- [ ] Async patterns used
- [ ] Caching implemented
- [ ] Batch processing where applicable
- [ ] Carbon footprint measured
